summaryrefslogtreecommitdiffstats
path: root/libkdenetwork
diff options
context:
space:
mode:
Diffstat (limited to 'libkdenetwork')
-rw-r--r--libkdenetwork/libgpgme-copy/assuan/assuan-defs.h2
-rw-r--r--libkdenetwork/libgpgme-copy/assuan/assuan.h4
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/ChangeLog2
3 files changed, 4 insertions, 4 deletions
diff --git a/libkdenetwork/libgpgme-copy/assuan/assuan-defs.h b/libkdenetwork/libgpgme-copy/assuan/assuan-defs.h
index 9ee417a92..fa04f0b29 100644
--- a/libkdenetwork/libgpgme-copy/assuan/assuan-defs.h
+++ b/libkdenetwork/libgpgme-copy/assuan/assuan-defs.h
@@ -310,7 +310,7 @@ char *stpcpy (char *dest, const char *src);
#define setenv _assuan_setenv
#define unsetenv _assuan_unsetenv
#define clearenv _assuan_clearenv
-int setenv (const char *name, const char *value, int tqreplace);
+int setenv (const char *name, const char *value, int replace);
#endif
#ifndef HAVE_PUTC_UNLOCKED
int putc_unlocked (int c, FILE *stream);
diff --git a/libkdenetwork/libgpgme-copy/gpgme/ChangeLog b/libkdenetwork/libgpgme-copy/gpgme/ChangeLog
index 4985741db..4f1038fb3 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/ChangeLog
+++ b/libkdenetwork/libgpgme-copy/gpgme/ChangeLog
@@ -362,7 +362,7 @@
to prototype.
* verify.c (parse_notation): Likewise for invocation.
* conversion.c (_gpgme_decode_percent_string): Likewise to
- declaration. If set, do not tqreplace '\0' characters with a
+ declaration. If set, do not replace '\0' characters with a
printable string.
* gpgme.h (struct _gpgme_key_sig): New field notations.
* ops.h (_gpgme_parse_notation): New prototype.
diff --git a/libkdenetwork/libgpgme-copy/assuan/assuan.h b/libkdenetwork/libgpgme-copy/assuan/assuan.h
index 3ae24248b..8d0a3960d 100644
--- a/libkdenetwork/libgpgme-copy/assuan/assuan.h
+++ b/libkdenetwork/libgpgme-copy/assuan/assuan.h
@@ -402,8 +402,8 @@ assuan_error_t assuan_set_okay_line (assuan_context_t ctx, const char *line);
assuan_error_t assuan_write_status (assuan_context_t ctx,
const char *keyword, const char *text);
-/* Negotiate a file descriptor. If LINE tqcontains "FD=N", returns N
- assuming a local file descriptor. If LINE tqcontains "FD" reads a
+/* Negotiate a file descriptor. If LINE contains "FD=N", returns N
+ assuming a local file descriptor. If LINE contains "FD" reads a
file descriptor via CTX and stores it in *RDF (the CTX must be
capable of passing file descriptors). */
assuan_error_t assuan_command_parse_fd (assuan_context_t ctx, char *line,